@@ -136,12 +136,12 @@ create_stacked <- function(data,
     rename(group = !!sym(hrvar)) %>% # Rename HRvar to `group`
     select(PersonId, group, metrics) %>%
     group_by(PersonId, group) %>%
-    summarise_at(vars(metrics), ~mean(.)) %>%
-    ungroup() %>%
+    summarise(across(.cols = all_of(metrics), .fns = ~mean(.)),
+      .groups = "drop") %>%
     mutate(Total = select(., metrics) %>% apply(1, sum)) %>%
     left_join(n_count, by = "group") %>%
     # Keep only groups above privacy threshold
-    filter(Employee_Count >= mingroup)
+    dplyr::filter(Employee_Count >= mingroup)
 
   myTableReturn <-
     myTable %>%
@@ -156,7 +156,7 @@ create_stacked <- function(data,
 
   totalTable <-
     plot_table %>%
-    filter(Metric == "Total") %>%
+    dplyr::filter(Metric == "Total") %>%
     group_by(group) %>%
     summarise(Total = mean(Value))
 
